Country class

Constructors

Country()

Properties

alpha3Code String
getter/setter pair
capital String
getter/setter pair
currency Currency
getter/setter pair
demonym String
getter/setter pair
flag String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
language Language
getter/setter pair
name String
getter/setter pair
numericCode int
getter/setter pair
population int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tld String
getter/setter pair
totalArea int
getter/setter pair
translation Translation
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited