Proxy class

Constructors

Proxy()

Properties

hashCode int
The hash code for this object.
no setterinherited
isBotnet bool
getter/setter pair
isDataCenter bool
getter/setter pair
isPublicProxy bool
getter/setter pair
isResidentialProxy bool
getter/setter pair
isScanner bool
getter/setter pair
isSpammer bool
getter/setter pair
isTor bool
getter/setter pair
isVpn bool
getter/setter pair
isWebCrawler bool
getter/setter pair
isWebProxy bool
getter/setter pair
lastSeen int
getter/setter pair
provider String
getter/setter pair
proxyType String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threat String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited