verifyip2location library
Support for doing something awesome.
More dartdocs go here.
Classes
- BaseHttpIkaResponse
- base class for http response
- City
- Continent
- Country
- Currency
- Geotargeting
- Language
- ParseLocation
- Proxy
- Region
- TimeZoneInfo
- Translation
Functions
-
getDnsWhois(
String ip2token, {int? plan, String? option, String? ip, String? domain}) → Future< HttpIkaWhoisService> - method to make an HTTP GET request with getDnsWhois.
-
getIpgeo(
String ip2token, {int? plan, String? option, String? ip, String? domain}) → Future< BaseHttpIkaResponse> - Package to verify personnal connexion by finding the geolacation of the person (City Name), region name, and country name Country Code if is used normal Proxy or tor / vpn you can find the position via latitude and longitude a botnet Malware infected devices. method to make an HTTP GET request getIpgeo.